@@ -9,10 +9,10 @@ use DateTime::Format::Human::Duration;
 use File::Basename qw(fileparse);
 use Format::Human::Bytes;
 use POE::Component::IRC::Plugin qw(PCI_EAT_NONE);
-use POE::Component::IRC::Common qw(NORMAL DARK_GREEN DARK_BLUE ORANGE TEAL);
+use POE::Component::IRC::Common qw(NORMAL DARK_GREEN DARK_BLUE ORANGE TEAL BROWN);
 use POE::Component::IRC::Plugin::FollowTail;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub new {
     my ($package, %args) = @_;
@@ -55,9 +55,9 @@ sub S_tail_input {
     my $input    = ${ $_[1] };
     return if $filename ne $self->{Torrent_log};
 
-    my ($action, $args) = split /,/, $input, 2;
+    my ($action, @args) = split /\t/, $input;
     my $method = "_${action}_torrent";
-    my $msg = $self->$method($args);
+    my $msg = $self->$method(@args);
     
     if (defined $msg) {
         for my $chan (@{ $self->{Channels} }) {
@@ -69,15 +69,9 @@ sub S_tail_input {
 }
 
 sub _inserted_new_torrent {
-    my ($self, $args) = @_;
-    my (undef, $hash, $bytes, undef, $file) = split /,/, $args, 5;
-    return if !defined $hash || !defined $bytes || !defined $file;
+    my ($self, $name, $user, $bytes) = @_;
 
-    my $name = fileparse($file);
-    $name =~ s/\.torrent$//;
-    my $user = getpwuid((stat $file)[4]);
     my $size = _fmt_bytes($bytes);
-
     my $msg = $self->{Color}
         ? DARK_BLUE.'Enqueued: '.ORANGE.$name.NORMAL." ($size, by $user)"
         : "Enqueued: $name ($size, by $user)";
@@ -86,18 +80,11 @@ sub _inserted_new_torrent {
 }
 
 sub _finished_torrent {
-    my ($self, $args) = @_;
-    my ($finished, $hash, $bytes, $rars, $file) = split /,/, $args, 5;
-    return if !defined $finished || !defined $hash || !defined $bytes || !defined $rars || !defined $file;
+    my ($self, $name, $enqueued, $finished, $bytes, $rars) = @_;
 
-    my $enqueued = (stat $file)[10];
     my $duration = _duration($enqueued, $finished);
-    my $name = fileparse($file);
-    $name =~ s/\.torrent$//;
-
     my $secs = $finished - $enqueued;
-    # Sometimes it's that fast, avoid division by zero
-    $secs = 1 if $secs == 0;
+    $secs = 1 if $secs == 0; # avoid division by zero
 
     my $bps = $bytes / $secs;
     my $size = _fmt_bytes($bps);
@@ -106,22 +93,21 @@ sub _finished_torrent {
     my $msg = $self->{Color}
         ? DARK_GREEN.'Finished: '.ORANGE.$name.NORMAL." in $duration ($rate)"
         : "Finished: $name in $duration ($rate)";
-    my $archives = $rars > 1 ? 'archives' : 'archive';
-    $msg .= "; $rars $archives to unrar" if $rars;
+
+    if ($rars > 0) {
+        my $archives = $rars > 1 ? 'archives' : 'archive';
+        $msg .= "; $rars $archives to unrar";
+    }
 
     return $msg;
 }
 
 sub _unrar_torrent {
-    my ($self, $args) = @_;
-    my ($start, $finish, $rars, $file) = split /,/, $args, 5;
-    return if !defined $start || !defined $finish || !defined $rars || !defined $file;
+    my ($self, $name, $start, $finish, $rars) = @_;
 
     my $duration = _duration($start, $finish);
-    my $name = fileparse($file);
-    $name =~ s/\.torrent$//;
-
     my $archives = $rars > 1 ? 'archives' : 'archive';
+
     my $msg = $self->{Color}
         ? TEAL.'Unrared: '.ORANGE.$name.NORMAL." in $duration ($rars $archives)"
         : "Unrared: $name in $duration ($rars $archives)";
@@ -129,6 +115,26 @@ sub _unrar_torrent {
     return $msg;
 }
 
+sub _erased_torrent {
+    my ($self, $name, $size_bytes, $down_bytes, $up_bytes, $ratio) = @_;
+    my $up = _fmt_bytes($up_bytes);
+
+    my $msg;
+    if ($size_bytes == $down_bytes) {
+        $msg = $self->{Color}
+            ? TEAL.'Removed: '.ORANGE.$name.NORMAL." (ratio: $ratio, uploaded: $up)"
+            : "Removed: $name (ratio: $ratio, uploaded: $up)";
+    }
+    else {
+        my $done = sprintf '%.f%', $down_bytes / $size_bytes * 100;
+        $msg = $self->{Color}
+            ? BROWN.'Aborted: '.ORANGE.$name.NORMAL." ($done done, ratio: $ratio, uploaded: $up)"
+            : "Aborted: $name ($done done, ratio: $ratio, uploaded: $up)";
+    }
+
+    return $msg;
+}
+
 sub _duration {
     my ($start, $finish) = @_;
 
@@ -139,7 +145,10 @@ sub _duration {
     return $span->format_duration($dur_obj);
 }
 
-sub _fmt_bytes { return Format::Human::Bytes::base2($_[0]) }
+sub _fmt_bytes {
+    my ($bytes) = @_;
+    return '0B' if $bytes == 0;
+    return Format::Human::Bytes::base2($_[0]) }
 
 1;
 
@@ -168,6 +177,19 @@ generated by the included L<irctor-queue> program and posts messages to
 IRC describing the events. See the documentation for L<irctor-queue>
 on how to set it up with RTorrent.
 
+ -MyBot:#channel- Enqueued: ubuntu-9.10-desktop-i386.iso (700MB, by hinrik)
+ -MyBot:#channel- Aborted: ubuntu-9.10-desktop-i386.iso (10% done, ratio: 0.05, up: 35MB)
+ -MyBot:#channel- Enqueued: ubuntu-9.10-desktop-amd64.iso (700MB, by hinrik)
+ -MyBot:#channel- Finished: ubuntu-9.10-desktop-amd64.iso (445kB/s)
+ -MyBot:#channel- Removed: ubuntu-9.10-desktop-amd64.iso (ratio: 2.00, up: 1400MB)
+
+And if you've got unraring enabled:
+
+ -MyBot:#channel- Enqueued: foobar (100MB, by hinrik)
+ -MyBot:#channel- Finished: foobar (100kB/s); 1 archive to unrar
+ -MyBot:#channel- Unrared: foobar in 5 seconds (1 archive)
+ -MyBot:#channel- Removed: foobar (ratio: 2.00, up: 200MB)
+
 =head1 METHODS
 
 =head2 C<new>
@@ -188,14 +210,6 @@ B<'Method'>, how you want messages to be delivered. Valid options are
 Returns a plugin object suitable for feeding to
 L<POE::Component::IRC|POE::Component::IRC>'s C<plugin_add> method.
 
-=head1 TODO
-
-Handle RTorrent restarts. Currently the torrent name will be replaced with
-the torrent hash after a restart.
-
-Handle Magnet links. RTorrent doesn't support them yet, but when it does,
-there won't be a torrent file laying around for us to look up.
-
 =head1 AUTHOR
 
 Hinrik E<Ouml>rn SigurE<eth>sson, hinrik.sig@gmail.com
